
package org.glassfish.jersey.internal;

import org.glassfish.jersey.internal.l10n.Localizable;
import org.glassfish.jersey.internal.l10n.LocalizableMessageFactory;
import org.glassfish.jersey.internal.l10n.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class LocalizationMessages {

    private final static LocalizableMessageFactory messageFactory = new LocalizableMessageFactory("org.glassfish.jersey.internal.localization");
    private final static Localizer localizer = new Localizer();

    public static Localizable localizableURI_BUILDER_SCHEMA_PART_OPAQUE() {
        return messageFactory.getMessage("uri.builder.schema.part.opaque");
    }

    /**
     * Schema specific part is opaque.
     * 
     */
    public static String URI_BUILDER_SCHEMA_PART_OPAQUE() {
        return localizer.localize(localizableURI_BUILDER_SCHEMA_PART_OPAQUE());
    }

    public static Localizable localizableDATE_IS_NULL() {
        return messageFactory.getMessage("date.is.null");
    }

    /**
     * Date is null.
     * 
     */
    public static String DATE_IS_NULL() {
        return localizer.localize(localizableDATE_IS_NULL());
    }

    public static Localizable localizablePROVIDER_NOT_ASSIGNABLE(Object arg0, Object arg1) {
        return messageFactory.getMessage("provider.not.assignable", arg0, arg1);
    }

    /**
     * Provider {0} can not be used because it is not assignable to {1}. This might be caused by clashing container-provided and application-bundled Jersey classes.
     * 
     */
    public static String PROVIDER_NOT_ASSIGNABLE(Object arg0, Object arg1) {
        return localizer.localize(localizablePROVIDER_NOT_ASSIGNABLE(arg0, arg1));
    }

    public static Localizable localizableILLEGAL_PROVIDER_CLASS_NAME(Object arg0) {
        return messageFactory.getMessage("illegal.provider.class.name", arg0);
    }

    /**
     * Illegal provider-class name: {0}.
     * 
     */
    public static String ILLEGAL_PROVIDER_CLASS_NAME(Object arg0) {
        return localizer.localize(localizableILLEGAL_PROVIDER_CLASS_NAME(arg0));
    }

    public static Localizable localizableRESPONSE_CLOSED() {
        return messageFactory.getMessage("response.closed");
    }

    /**
     * Response is closed.
     * 
     */
    public static String RESPONSE_CLOSED() {
        return localizer.localize(localizableRESPONSE_CLOSED());
    }

    public static Localizable localizableTYPE_TO_CLASS_CONVERSION_NOT_SUPPORTED(Object arg0) {
        return messageFactory.getMessage("type.to.class.conversion.not.supported", arg0);
    }

    /**
     * Type-to-class conversion not supported for: {0}.
     * 
     */
    public static String TYPE_TO_CLASS_CONVERSION_NOT_SUPPORTED(Object arg0) {
        return localizer.localize(localizableTYPE_TO_CLASS_CONVERSION_NOT_SUPPORTED(arg0));
    }

    public static Localizable localizableILLEGAL_LOAD_FACTOR(Object arg0) {
        return messageFactory.getMessage("illegal.load.factor", arg0);
    }

    /**
     * Illegal load factor: {0}.
     * 
     */
    public static String ILLEGAL_LOAD_FACTOR(Object arg0) {
        return localizer.localize(localizableILLEGAL_LOAD_FACTOR(arg0));
    }

    public static Localizable localizableWARNING_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(Object arg0, Object arg1, Object arg2, Object arg3) {
        return messageFactory.getMessage("warning.provider.constrainedTo.wrong.package", arg0, arg1, arg2, arg3);
    }

    /**
     * A registered provider {0} constrained (via @ConstrainedTo) to {1} runtime implements interface {2} which is only usable in a {3} runtime context.
     * 
     */
    public static String WARNING_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(Object arg0, Object arg1, Object arg2, Object arg3) {
        return localizer.localize(localizableWARNING_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(arg0, arg1, arg2, arg3));
    }

    public static Localizable localizableERROR_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(Object arg0, Object arg1) {
        return messageFactory.getMessage("error.provider.constrainedTo.wrong.package", arg0, arg1);
    }

    /**
     * A registered provider {0} is constrained (via @ConstrainedTo) to {1} runtime but does not implement any provider interface usable in the runtime.
     * 
     */
    public static String ERROR_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(Object arg0, Object arg1) {
        return localizer.localize(localizableERROR_PROVIDER_CONSTRAINED_TO_WRONG_PACKAGE(arg0, arg1));
    }

    public static Localizable localizableTEMPLATE_PARAM_NULL() {
        return messageFactory.getMessage("template.param.null");
    }

    /**
     * One or more of template keys or values are null.
     * 
     */
    public static String TEMPLATE_PARAM_NULL() {
        return localizer.localize(localizableTEMPLATE_PARAM_NULL());
    }

    public static Localizable localizableCOOKIE_IS_NULL() {
        return messageFactory.getMessage("cookie.is.null");
    }

    /**
     * Cookie is null.
     * 
     */
    public static String COOKIE_IS_NULL() {
        return localizer.localize(localizableCOOKIE_IS_NULL());
    }

    public static Localizable localizableFEATURE_HAS_ALREADY_BEEN_ENABLED(Object arg0) {
        return messageFactory.getMessage("feature.has.already.been.enabled", arg0);
    }

    /**
     * Feature [{0}] has already been enabled.
     * 
     */
    public static String FEATURE_HAS_ALREADY_BEEN_ENABLED(Object arg0) {
        return localizer.localize(localizableFEATURE_HAS_ALREADY_BEEN_ENABLED(arg0));
    }

    public static Localizable localizableURI_BUILDER_ANNOTATEDELEMENT_PATH_ANNOTATION_MISSING(Object arg0) {
        return messageFactory.getMessage("uri.builder.annotatedelement.path.annotation.missing", arg0);
    }

    /**
     * The annotated element "{0}" is not annotated with @Path.
     * 
     */
    public static String URI_BUILDER_ANNOTATEDELEMENT_PATH_ANNOTATION_MISSING(Object arg0) {
        return localizer.localize(localizableURI_BUILDER_ANNOTATEDELEMENT_PATH_ANNOTATION_MISSING(arg0));
    }

    public static Localizable localizableURI_BUILDER_PATH_SEGMENT_NULL() {
        return messageFactory.getMessage("uri.builder.path.segment.null");
    }

    /**
     * Path segment is null.
     * 
     */
    public static String URI_BUILDER_PATH_SEGMENT_NULL() {
        return localizer.localize(localizableURI_BUILDER_PATH_SEGMENT_NULL());
    }

    public static Localizable localizableURI_COMPONENT_INVALID_CHARACTER(Object arg0, Object arg1, Object arg2, Object arg3) {
        return messageFactory.getMessage("uri.component.invalid.character", arg0, arg1, arg2, arg3);
    }

    /**
     * The string "{0}" for the URI component {1} contains an invalid character, ''{2}'', at index {3}.
     * 
     */
    public static String URI_COMPONENT_INVALID_CHARACTER(Object arg0, Object arg1, Object arg2, Object arg3) {
        return localizer.localize(localizableURI_COMPONENT_INVALID_CHARACTER(arg0, arg1, arg2, arg3));
    }

    public static Localizable localizableERROR_NOTFOUND_MESSAGEBODYWRITER(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("error.notfound.messagebodywriter", arg0, arg1, arg2);
    }

    /**
     * MessageBodyWriter not found for media type={0}, type={1}, genericType={2}.
     * 
     */
    public static String ERROR_NOTFOUND_MESSAGEBODYWRITER(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableERROR_NOTFOUND_MESSAGEBODYWRITER(arg0, arg1, arg2));
    }

    public static Localizable localizableERROR_INTERCEPTOR_WRITER_PROCEED() {
        return messageFactory.getMessage("error.interceptor.writer.proceed");
    }

    /**
     * Last writer interceptor in the chain called the method proceed.
     * 
     */
    public static String ERROR_INTERCEPTOR_WRITER_PROCEED() {
        return localizer.localize(localizableERROR_INTERCEPTOR_WRITER_PROCEED());
    }

    public static Localizable localizableEXCEPTION_CAUGHT_WHILE_LOADING_SPI_PROVIDERS() {
        return messageFactory.getMessage("exception.caught.while.loading.spi.providers");
    }

    /**
     * Exception caught while loading SPI providers.
     * 
     */
    public static String EXCEPTION_CAUGHT_WHILE_LOADING_SPI_PROVIDERS() {
        return localizer.localize(localizableEXCEPTION_CAUGHT_WHILE_LOADING_SPI_PROVIDERS());
    }

    public static Localizable localizableERROR_ENTITY_PROVIDER_BASICTYPES_CHARACTER_MORECHARS() {
        return messageFactory.getMessage("error.entity.provider.basictypes.character.morechars");
    }

    /**
     * A single character expected in the entity input stream.
     * 
     */
    public static String ERROR_ENTITY_PROVIDER_BASICTYPES_CHARACTER_MORECHARS() {
        return localizer.localize(localizableERROR_ENTITY_PROVIDER_BASICTYPES_CHARACTER_MORECHARS());
    }

    public static Localizable localizableMATRIX_PARAM_NULL() {
        return messageFactory.getMessage("matrix.param.null");
    }

    /**
     * One or more of matrix value parameters are null.
     * 
     */
    public static String MATRIX_PARAM_NULL() {
        return localizer.localize(localizableMATRIX_PARAM_NULL());
    }

    public static Localizable localizableERROR_NOTFOUND_MESSAGEBODYREADER(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("error.notfound.messagebodyreader", arg0, arg1, arg2);
    }

    /**
     * MessageBodyReader not found for media type={0}, type={1}, genericType={2}.
     * 
     */
    public static String ERROR_NOTFOUND_MESSAGEBODYREADER(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableERROR_NOTFOUND_MESSAGEBODYREADER(arg0, arg1, arg2));
    }

    public static Localizable localizableURI_COMPONENT_ENCODED_OCTET_MALFORMED(Object arg0) {
        return messageFactory.getMessage("uri.component.encoded.octet.malformed", arg0);
    }

    /**
     * Malformed percent-encoded octet at index {0}.
     * 
     */
    public static String URI_COMPONENT_ENCODED_OCTET_MALFORMED(Object arg0) {
        return localizer.localize(localizableURI_COMPONENT_ENCODED_OCTET_MALFORMED(arg0));
    }

    public static Localizable localizableCONFIGURABLE_NOT_MODIFIABLE() {
        return messageFactory.getMessage("configurable.not.modifiable");
    }

    /**
     * The configuration is not modifiable in this context.
     * 
     */
    public static String CONFIGURABLE_NOT_MODIFIABLE() {
        return localizer.localize(localizableCONFIGURABLE_NOT_MODIFIABLE());
    }

    public static Localizable localizableUSING_DEFAULT_RESPONSE_EXECUTOR(Object arg0) {
        return messageFactory.getMessage("using.default.response.executor", arg0);
    }

    /**
     * "Using default responding executor [{0}]."
     * 
     */
    public static String USING_DEFAULT_RESPONSE_EXECUTOR(Object arg0) {
        return localizer.localize(localizableUSING_DEFAULT_RESPONSE_EXECUTOR(arg0));
    }

    public static Localizable localizableINVALID_PORT() {
        return messageFactory.getMessage("invalid.port");
    }

    /**
     * Invalid port value.
     * 
     */
    public static String INVALID_PORT() {
        return localizer.localize(localizableINVALID_PORT());
    }

    public static Localizable localizableUSING_CUSTOM_RESPONSE_EXECUTOR(Object arg0, Object arg1) {
        return messageFactory.getMessage("using.custom.response.executor", arg0, arg1);
    }

    /**
     * "Using custom responding executor [{0}] provided by [{1}]."
     * 
     */
    public static String USING_CUSTOM_RESPONSE_EXECUTOR(Object arg0, Object arg1) {
        return localizer.localize(localizableUSING_CUSTOM_RESPONSE_EXECUTOR(arg0, arg1));
    }

    public static Localizable localizableLOCALE_IS_NULL() {
        return messageFactory.getMessage("locale.is.null");
    }

    /**
     * Locale is null.
     * 
     */
    public static String LOCALE_IS_NULL() {
        return localizer.localize(localizableLOCALE_IS_NULL());
    }

    public static Localizable localizableILLEGAL_CONFIG_SYNTAX() {
        return messageFactory.getMessage("illegal.config.syntax");
    }

    /**
     * Illegal configuration-file syntax.
     * 
     */
    public static String ILLEGAL_CONFIG_SYNTAX() {
        return localizer.localize(localizableILLEGAL_CONFIG_SYNTAX());
    }

    public static Localizable localizableQUERY_PARAM_NULL() {
        return messageFactory.getMessage("query.param.null");
    }

    /**
     * One or more of query value parameters are null.
     * 
     */
    public static String QUERY_PARAM_NULL() {
        return localizer.localize(localizableQUERY_PARAM_NULL());
    }

    public static Localizable localizableERROR_PROCESSING_MESSAGEBODY() {
        return messageFactory.getMessage("error.processing.messagebody");
    }

    /**
     * Exception during processing (read/write) of the message body.
     * 
     */
    public static String ERROR_PROCESSING_MESSAGEBODY() {
        return localizer.localize(localizableERROR_PROCESSING_MESSAGEBODY());
    }

    public static Localizable localizableURI_BUILDER_METHODNAME_NOT_SPECIFIED(Object arg0, Object arg1) {
        return messageFactory.getMessage("uri.builder.methodname.not.specified", arg0, arg1);
    }

    /**
     * The method named "{0}" is not specified by {1}.
     * 
     */
    public static String URI_BUILDER_METHODNAME_NOT_SPECIFIED(Object arg0, Object arg1) {
        return localizer.localize(localizableURI_BUILDER_METHODNAME_NOT_SPECIFIED(arg0, arg1));
    }

    public static Localizable localizablePROVIDER_CANNOT_BE_NULL() {
        return messageFactory.getMessage("provider.cannot.be.null");
    }

    /**
     * Registering provider instance cannot be null.
     * 
     */
    public static String PROVIDER_CANNOT_BE_NULL() {
        return localizer.localize(localizablePROVIDER_CANNOT_BE_NULL());
    }

    public static Localizable localizableERROR_INTERCEPTOR_READER_PROCEED() {
        return messageFactory.getMessage("error.interceptor.reader.proceed");
    }

    /**
     * Last reader interceptor in the chain called the method proceed.
     * 
     */
    public static String ERROR_INTERCEPTOR_READER_PROCEED() {
        return localizer.localize(localizableERROR_INTERCEPTOR_READER_PROCEED());
    }

    public static Localizable localizableILLEGAL_INVOCATION_CONTEXT_STATE(Object arg0, Object arg1) {
        return messageFactory.getMessage("illegal.invocation.context.state", arg0, arg1);
    }

    /**
     * Invocation context is in illegal state "{0}" for "{1}" operation.
     * 
     */
    public static String ILLEGAL_INVOCATION_CONTEXT_STATE(Object arg0, Object arg1) {
        return localizer.localize(localizableILLEGAL_INVOCATION_CONTEXT_STATE(arg0, arg1));
    }

    public static Localizable localizableSAX_XDK_NO_SECURITY_FEATURES() {
        return messageFactory.getMessage("sax.xdk.no.security.features");
    }

    /**
     * Using XDK. No security features will be enabled for the SAX parser.
     * 
     */
    public static String SAX_XDK_NO_SECURITY_FEATURES() {
        return localizer.localize(localizableSAX_XDK_NO_SECURITY_FEATURES());
    }

    public static Localizable localizableCACHE_CONTROL_IS_NULL() {
        return messageFactory.getMessage("cache.control.is.null");
    }

    /**
     * Cache control is null.
     * 
     */
    public static String CACHE_CONTROL_IS_NULL() {
        return localizer.localize(localizableCACHE_CONTROL_IS_NULL());
    }

    public static Localizable localizablePROVIDER_CLASS_CANNOT_BE_NULL() {
        return messageFactory.getMessage("provider.class.cannot.be.null");
    }

    /**
     * Registering provider class cannot be null.
     * 
     */
    public static String PROVIDER_CLASS_CANNOT_BE_NULL() {
        return localizer.localize(localizablePROVIDER_CLASS_CANNOT_BE_NULL());
    }

    public static Localizable localizableENTITY_TAG_IS_NULL() {
        return messageFactory.getMessage("entity.tag.is.null");
    }

    /**
     * Entity tag is null.
     * 
     */
    public static String ENTITY_TAG_IS_NULL() {
        return localizer.localize(localizableENTITY_TAG_IS_NULL());
    }

    public static Localizable localizableERROR_ENTITY_STREAM_CLOSED() {
        return messageFactory.getMessage("error.entity.stream.closed");
    }

    /**
     * Entity input stream has already been closed.
     * 
     */
    public static String ERROR_ENTITY_STREAM_CLOSED() {
        return localizer.localize(localizableERROR_ENTITY_STREAM_CLOSED());
    }

    public static Localizable localizableDEPENDENT_CLASS_OF_PROVIDER_NOT_FOUND(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("dependent.class.of.provider.not.found", arg0, arg1, arg2);
    }

    /**
     * A dependent class, {0}, of the class {1} implementing the provider {2} is not found. The provider implementation is ignored.
     * 
     */
    public static String DEPENDENT_CLASS_OF_PROVIDER_NOT_FOUND(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableDEPENDENT_CLASS_OF_PROVIDER_NOT_FOUND(arg0, arg1, arg2));
    }

    public static Localizable localizableERROR_UNMARSHALLING_JAXB(Object arg0) {
        return messageFactory.getMessage("error.unmarshalling.jaxb", arg0);
    }

    /**
     * Error un-marshalling JAXB object of type: {0}.
     * 
     */
    public static String ERROR_UNMARSHALLING_JAXB(Object arg0) {
        return localizer.localize(localizableERROR_UNMARSHALLING_JAXB(arg0));
    }

    public static Localizable localizableERROR_CAUGHT_WHILE_LOADING_SPI_PROVIDERS() {
        return messageFactory.getMessage("error.caught.while.loading.spi.providers");
    }

    /**
     * Error caught while loading SPI providers.
     * 
     */
    public static String ERROR_CAUGHT_WHILE_LOADING_SPI_PROVIDERS() {
        return localizer.localize(localizableERROR_CAUGHT_WHILE_LOADING_SPI_PROVIDERS());
    }

    public static Localizable localizableINVOCATION_FAILED(Object arg0) {
        return messageFactory.getMessage("invocation.failed", arg0);
    }

    /**
     * Invocation of a {0} method on a request execution callback has failed.
     * 
     */
    public static String INVOCATION_FAILED(Object arg0) {
        return localizer.localize(localizableINVOCATION_FAILED(arg0));
    }

    public static Localizable localizableDEPENDENT_CLASS_OF_PROVIDER_FORMAT_ERROR(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("dependent.class.of.provider.format.error", arg0, arg1, arg2);
    }

    /**
     * {0}. A dependent class of the class {1} implementing the provider {2} is malformed. The provider implementation is ignored. Check if the malformed class is part of a stubbed jar that used for compiling only.
     * 
     */
    public static String DEPENDENT_CLASS_OF_PROVIDER_FORMAT_ERROR(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableDEPENDENT_CLASS_OF_PROVIDER_FORMAT_ERROR(arg0, arg1, arg2));
    }

    public static Localizable localizablePROVIDER_CLASS_COULD_NOT_BE_LOADED(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("provider.class.could.not.be.loaded", arg0, arg1, arg2);
    }

    /**
     * The class {0} implementing provider {1} could not be loaded: {2}
     * 
     */
    public static String PROVIDER_CLASS_COULD_NOT_BE_LOADED(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizablePROVIDER_CLASS_COULD_NOT_BE_LOADED(arg0, arg1, arg2));
    }

    public static Localizable localizableREQUEST_EXECUTION_FAILED() {
        return messageFactory.getMessage("request.execution.failed");
    }

    /**
     * Request execution has failed.
     * 
     */
    public static String REQUEST_EXECUTION_FAILED() {
        return localizer.localize(localizableREQUEST_EXECUTION_FAILED());
    }

    public static Localizable localizableCALLBACK_METHOD_INVOCATION_FAILED(Object arg0, Object arg1) {
        return messageFactory.getMessage("callback.method.invocation.failed", arg0, arg1);
    }

    /**
     * Invocation of a {0} method on a request execution callback has failed on thread {1}.
     * 
     */
    public static String CALLBACK_METHOD_INVOCATION_FAILED(Object arg0, Object arg1) {
        return localizer.localize(localizableCALLBACK_METHOD_INVOCATION_FAILED(arg0, arg1));
    }

    public static Localizable localizableUSING_CUSTOM_REQUEST_EXECUTOR(Object arg0, Object arg1) {
        return messageFactory.getMessage("using.custom.request.executor", arg0, arg1);
    }

    /**
     * "Using custom requesting executor [{0}] provided by [{1}]."
     * 
     */
    public static String USING_CUSTOM_REQUEST_EXECUTOR(Object arg0, Object arg1) {
        return localizer.localize(localizableUSING_CUSTOM_REQUEST_EXECUTOR(arg0, arg1));
    }

    public static Localizable localizableMESSAGE_CONTENT_INPUT_STREAM_CLOSE_FAILED() {
        return messageFactory.getMessage("message.content.input.stream.close.failed");
    }

    /**
     * Error closing message content input stream.
     * 
     */
    public static String MESSAGE_CONTENT_INPUT_STREAM_CLOSE_FAILED() {
        return localizer.localize(localizableMESSAGE_CONTENT_INPUT_STREAM_CLOSE_FAILED());
    }

    public static Localizable localizableNO_CONTAINER_AVAILABLE() {
        return messageFactory.getMessage("no.container.available");
    }

    /**
     * No container available.
     * 
     */
    public static String NO_CONTAINER_AVAILABLE() {
        return localizer.localize(localizableNO_CONTAINER_AVAILABLE());
    }

    public static Localizable localizableERROR_READING_ENTITY_FROM_INPUT_STREAM() {
        return messageFactory.getMessage("error.reading.entity.from.input.stream");
    }

    /**
     * Error reading entity from input stream.
     * 
     */
    public static String ERROR_READING_ENTITY_FROM_INPUT_STREAM() {
        return localizer.localize(localizableERROR_READING_ENTITY_FROM_INPUT_STREAM());
    }

    public static Localizable localizableREQUEST_SUSPEND_FAILED(Object arg0) {
        return messageFactory.getMessage("request.suspend.failed", arg0);
    }

    /**
     * Failed to suspend request invocation context in state "{0}".
     * 
     */
    public static String REQUEST_SUSPEND_FAILED(Object arg0) {
        return localizer.localize(localizableREQUEST_SUSPEND_FAILED(arg0));
    }

    public static Localizable localizableURI_COMPONENT_ENCODED_OCTET_INVALID_DIGIT(Object arg0, Object arg1) {
        return messageFactory.getMessage("uri.component.encoded.octet.invalid.digit", arg0, arg1);
    }

    /**
     * Malformed percent-encoded octet at index {0}, invalid hexadecimal digit ''{1}''.
     * 
     */
    public static String URI_COMPONENT_ENCODED_OCTET_INVALID_DIGIT(Object arg0, Object arg1) {
        return localizer.localize(localizableURI_COMPONENT_ENCODED_OCTET_INVALID_DIGIT(arg0, arg1));
    }

    public static Localizable localizableERROR_PROVIDER_AND_RESOURCE_CONSTRAINED_TO_IGNORED(Object arg0) {
        return messageFactory.getMessage("error.provider.and.resource.constrainedTo.ignored", arg0);
    }

    /**
     * Due to constraint configuration problems the implementations of providers in the resource class {0} will be ignored. However, the resource class will be loaded and used as an resource.
     * 
     */
    public static String ERROR_PROVIDER_AND_RESOURCE_CONSTRAINED_TO_IGNORED(Object arg0) {
        return localizer.localize(localizableERROR_PROVIDER_AND_RESOURCE_CONSTRAINED_TO_IGNORED(arg0));
    }

    public static Localizable localizableUNABLE_TO_PARSE_HEADER_VALUE(Object arg0, Object arg1) {
        return messageFactory.getMessage("unable.to.parse.header.value", arg0, arg1);
    }

    /**
     * Unable to parse "{0}" header value: "{1}"
     * 
     */
    public static String UNABLE_TO_PARSE_HEADER_VALUE(Object arg0, Object arg1) {
        return localizer.localize(localizableUNABLE_TO_PARSE_HEADER_VALUE(arg0, arg1));
    }

    public static Localizable localizableERROR_PROVIDER_CONSTRAINED_TO_IGNORED(Object arg0) {
        return messageFactory.getMessage("error.provider.constrainedTo.ignored", arg0);
    }

    /**
     * Due to constraint configuration problems the provider {0} will be ignored.
     * 
     */
    public static String ERROR_PROVIDER_CONSTRAINED_TO_IGNORED(Object arg0) {
        return localizer.localize(localizableERROR_PROVIDER_CONSTRAINED_TO_IGNORED(arg0));
    }

    public static Localizable localizableLINK_IS_NULL() {
        return messageFactory.getMessage("link.is.null");
    }

    /**
     * Link is null.
     * 
     */
    public static String LINK_IS_NULL() {
        return localizer.localize(localizableLINK_IS_NULL());
    }

    public static Localizable localizableERROR_PROVIDER_REGISTERED_WRONG_RUNTIME(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("error.provider.registered.wrong.runtime", arg0, arg1, arg2);
    }

    /**
     * A provider {0} registered in {1} runtime implements only {2} provider interfaces.
     * 
     */
    public static String ERROR_PROVIDER_REGISTERED_WRONG_RUNTIME(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableERROR_PROVIDER_REGISTERED_WRONG_RUNTIME(arg0, arg1, arg2));
    }

    public static Localizable localizableSAX_CANNOT_ENABLE_SECURE_PROCESSING_FEATURE() {
        return messageFactory.getMessage("sax.cannot.enable.secure.processing.feature");
    }

    /**
     * JAXP feature XMLConstants.FEATURE_SECURE_PROCESSING cannot be set on a SAXParserFactory. External general entity processing is disabled but other potential security related features will not be enabled.
     * 
     */
    public static String SAX_CANNOT_ENABLE_SECURE_PROCESSING_FEATURE() {
        return localizer.localize(localizableSAX_CANNOT_ENABLE_SECURE_PROCESSING_FEATURE());
    }

    public static Localizable localizablePROVIDER_COULD_NOT_BE_CREATED(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("provider.could.not.be.created", arg0, arg1, arg2);
    }

    /**
     * The class {0} implementing provider {1} could not be instantiated: {2}
     * 
     */
    public static String PROVIDER_COULD_NOT_BE_CREATED(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizablePROVIDER_COULD_NOT_BE_CREATED(arg0, arg1, arg2));
    }

    public static Localizable localizableERROR_PROVIDER_CONSTRAINED_TO_WRONG_RUNTIME(Object arg0, Object arg1, Object arg2) {
        return messageFactory.getMessage("error.provider.constrainedTo.wrong.runtime", arg0, arg1, arg2);
    }

    /**
     * A provider {0} registered in {2} runtime is constrained (via @ConstrainedTo) to {1} runtime.
     * 
     */
    public static String ERROR_PROVIDER_CONSTRAINED_TO_WRONG_RUNTIME(Object arg0, Object arg1, Object arg2) {
        return localizer.localize(localizableERROR_PROVIDER_CONSTRAINED_TO_WRONG_RUNTIME(arg0, arg1, arg2));
    }

    public static Localizable localizableURI_IS_NULL() {
        return messageFactory.getMessage("uri.is.null");
    }

    /**
     * Uri is null.
     * 
     */
    public static String URI_IS_NULL() {
        return localizer.localize(localizableURI_IS_NULL());
    }

    public static Localizable localizableURI_BUILDER_SCHEME_PART_NULL() {
        return messageFactory.getMessage("uri.builder.scheme.part.null");
    }

    /**
     * Supplied scheme-specific part parameter is null.
     * 
     */
    public static String URI_BUILDER_SCHEME_PART_NULL() {
        return localizer.localize(localizableURI_BUILDER_SCHEME_PART_NULL());
    }

    public static Localizable localizableURI_BUILDER_CLASS_PATH_ANNOTATION_MISSING(Object arg0) {
        return messageFactory.getMessage("uri.builder.class.path.annotation.missing", arg0);
    }

    /**
     * The class, {0} is not annotated with @Path.
     * 
     */
    public static String URI_BUILDER_CLASS_PATH_ANNOTATION_MISSING(Object arg0) {
        return localizer.localize(localizableURI_BUILDER_CLASS_PATH_ANNOTATION_MISSING(arg0));
    }

    public static Localizable localizableSAX_CANNOT_ENABLE_SECURITY_FEATURES() {
        return messageFactory.getMessage("sax.cannot.enable.security.features");
    }

    /**
     * Security features for the SAX parser could not be enabled.
     * 
     */
    public static String SAX_CANNOT_ENABLE_SECURITY_FEATURES() {
        return localizer.localize(localizableSAX_CANNOT_ENABLE_SECURITY_FEATURES());
    }

    public static Localizable localizableEXCEPTION_MAPPER_SUPPORTED_TYPE_UNKNOWN(Object arg0) {
        return messageFactory.getMessage("exception.mapper.supported.type.unknown", arg0);
    }

    /**
     * Unable to retrieve the supported exception type for a registered exception mapper service class "{0}".
     * 
     */
    public static String EXCEPTION_MAPPER_SUPPORTED_TYPE_UNKNOWN(Object arg0) {
        return localizer.localize(localizableEXCEPTION_MAPPER_SUPPORTED_TYPE_UNKNOWN(arg0));
    }

    public static Localizable localizableURI_BUILDER_URI_PART_FRAGMENT(Object arg0, Object arg1) {
        return messageFactory.getMessage("uri.builder.uri.part.fragment", arg0, arg1);
    }

    /**
     * Supplied scheme-specific URI part "{0}" contains URI Fragment component: {1}.
     * 
     */
    public static String URI_BUILDER_URI_PART_FRAGMENT(Object arg0, Object arg1) {
        return localizer.localize(localizableURI_BUILDER_URI_PART_FRAGMENT(arg0, arg1));
    }

    public static Localizable localizableTOO_MANY_HEADER_VALUES(Object arg0, Object arg1) {
        return messageFactory.getMessage("too.many.header.values", arg0, arg1);
    }

    /**
     * Too many "{0}" header values: "{1}"
     * 
     */
    public static String TOO_MANY_HEADER_VALUES(Object arg0, Object arg1) {
        return localizer.localize(localizableTOO_MANY_HEADER_VALUES(arg0, arg1));
    }

    public static Localizable localizableMESSAGE_CONTENT_BUFFERING_FAILED() {
        return messageFactory.getMessage("message.content.buffering.failed");
    }

    /**
     * Failed to buffer the message content input stream.
     * 
     */
    public static String MESSAGE_CONTENT_BUFFERING_FAILED() {
        return localizer.localize(localizableMESSAGE_CONTENT_BUFFERING_FAILED());
    }

    public static Localizable localizablePROVIDER_NOT_FOUND(Object arg0, Object arg1) {
        return messageFactory.getMessage("provider.not.found", arg0, arg1);
    }

    /**
     * The class {0} implementing the provider {1} is not found. The provider implementation is ignored.
     * 
     */
    public static String PROVIDER_NOT_FOUND(Object arg0, Object arg1) {
        return localizer.localize(localizablePROVIDER_NOT_FOUND(arg0, arg1));
    }

    public static Localizable localizableILLEGAL_INITIAL_CAPACITY(Object arg0) {
        return messageFactory.getMessage("illegal.initial.capacity", arg0);
    }

    /**
     * Illegal initial capacity: {0}.
     * 
     */
    public static String ILLEGAL_INITIAL_CAPACITY(Object arg0) {
        return localizer.localize(localizableILLEGAL_INITIAL_CAPACITY(arg0));
    }

    public static Localizable localizableUSING_DEFAULT_REQUEST_EXECUTOR(Object arg0) {
        return messageFactory.getMessage("using.default.request.executor", arg0);
    }

    /**
     * "Using default requesting executor [{0}]."
     * 
     */
    public static String USING_DEFAULT_REQUEST_EXECUTOR(Object arg0) {
        return localizer.localize(localizableUSING_DEFAULT_REQUEST_EXECUTOR(arg0));
    }

    public static Localizable localizableSTRING_IS_NULL() {
        return messageFactory.getMessage("string.is.null");
    }

    /**
     * String is null.
     * 
     */
    public static String STRING_IS_NULL() {
        return localizer.localize(localizableSTRING_IS_NULL());
    }

    public static Localizable localizableURI_BUILDER_SCHEME_PART_UNEXPECTED_COMPONENT(Object arg0, Object arg1) {
        return messageFactory.getMessage("uri.builder.scheme.part.unexpected.component", arg0, arg1);
    }

    /**
     * Supplied scheme-specific URI part "{0}" contains unexpected URI Scheme component: {1}.
     * 
     */
    public static String URI_BUILDER_SCHEME_PART_UNEXPECTED_COMPONENT(Object arg0, Object arg1) {
        return localizer.localize(localizableURI_BUILDER_SCHEME_PART_UNEXPECTED_COMPONENT(arg0, arg1));
    }

    public static Localizable localizableNEW_COOKIE_IS_NULL() {
        return messageFactory.getMessage("new.cookie.is.null");
    }

    /**
     * New cookie is null.
     * 
     */
    public static String NEW_COOKIE_IS_NULL() {
        return localizer.localize(localizableNEW_COOKIE_IS_NULL());
    }

    public static Localizable localizableMEDIA_TYPE_IS_NULL() {
        return messageFactory.getMessage("media.type.is.null");
    }

    /**
     * Media type is null.
     * 
     */
    public static String MEDIA_TYPE_IS_NULL() {
        return localizer.localize(localizableMEDIA_TYPE_IS_NULL());
    }

    public static Localizable localizableREQUEST_CANCEL_FAILED(Object arg0) {
        return messageFactory.getMessage("request.cancel.failed", arg0);
    }

    /**
     * Failed to cancel request invocation context in state "{0}".
     * 
     */
    public static String REQUEST_CANCEL_FAILED(Object arg0) {
        return localizer.localize(localizableREQUEST_CANCEL_FAILED(arg0));
    }

    public static Localizable localizableINVALID_HOST() {
        return messageFactory.getMessage("invalid.host");
    }

    /**
     * Invalid host name.
     * 
     */
    public static String INVALID_HOST() {
        return localizer.localize(localizableINVALID_HOST());
    }

    public static Localizable localizableREQUEST_SUSPENDED_RESPONSE_IGNORED(Object arg0) {
        return messageFactory.getMessage("request.suspended.response.ignored", arg0);
    }

    /**
     * Request processing suspended - response returned by inflector ignored: {0}
     * 
     */
    public static String REQUEST_SUSPENDED_RESPONSE_IGNORED(Object arg0) {
        return localizer.localize(localizableREQUEST_SUSPENDED_RESPONSE_IGNORED(arg0));
    }

    public static Localizable localizableMESSAGE_CONTENT_BUFFER_RESET_FAILED() {
        return messageFactory.getMessage("message.content.buffer.reset.failed");
    }

    /**
     * Error resetting the buffered message content input stream.
     * 
     */
    public static String MESSAGE_CONTENT_BUFFER_RESET_FAILED() {
        return localizer.localize(localizableMESSAGE_CONTENT_BUFFER_RESET_FAILED());
    }

    public static Localizable localizableERROR_ENTITY_PROVIDER_BASICTYPES_CONSTRUCTOR(Object arg0) {
        return messageFactory.getMessage("error.entity.provider.basictypes.constructor", arg0);
    }

    /**
     * Error converting entity to {0} type by single String constructor.
     * 
     */
    public static String ERROR_ENTITY_PROVIDER_BASICTYPES_CONSTRUCTOR(Object arg0) {
        return localizer.localize(localizableERROR_ENTITY_PROVIDER_BASICTYPES_CONSTRUCTOR(arg0));
    }

    public static Localizable localizableERROR_ENTITY_PROVIDER_BASICTYPES_UNKWNOWN(Object arg0) {
        return messageFactory.getMessage("error.entity.provider.basictypes.unkwnown", arg0);
    }

    /**
     * Unsupported basic type {0}.
     * 
     */
    public static String ERROR_ENTITY_PROVIDER_BASICTYPES_UNKWNOWN(Object arg0) {
        return localizer.localize(localizableERROR_ENTITY_PROVIDER_BASICTYPES_UNKWNOWN(arg0));
    }

    public static Localizable localizablePARAM_NULL(Object arg0) {
        return messageFactory.getMessage("param.null", arg0);
    }

    /**
     * "{0}" parameter is null.
     * 
     */
    public static String PARAM_NULL(Object arg0) {
        return localizer.localize(localizablePARAM_NULL(arg0));
    }

}
